@@ -1,6 +1,6 @@
 from git_networkx.git_networkx import GitNX
 from git_networkx.git_node import *
 
-__version__ = "2.0.2"
-__package__="git-networkx"
+__version__ = "2.1.2"
+__package__="git_networkx"
 
